A simple printer of nested lists

A simple printer of nested lists that exists as an aid to print the
nested Python lists on their own lines.

This is the README file for the project.

The file should use UTF-8 encoding and be written using ReStructured
Text. It will be used to generate the project webpage on PyPI and will
be displayed as the project homepage on common code-hosting services,
and should be written for that purpose.

Typical contents for this file would include an overview of the project,
basic usage examples, etc. Generally, including the project changelog in
here is not a good idea, although a simple "What's New" section for the
most recent version may be appropriate.
